package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaTrain;

public interface IBisTtsaTrainService {
    BisTtsaTrain selectBisTtsaTrainByGuid(String guid);
    List<BisTtsaTrain> selectBisTtsaTrainList(BisTtsaTrain bisTtsaTrain);
    int insertBisTtsaTrain(BisTtsaTrain bisTtsaTrain);
    int updateBisTtsaTrain(BisTtsaTrain bisTtsaTrain);
    int deleteBisTtsaTrainByGuid(String guid);
    int deleteBisTtsaTrainByGuids(String[] guids);
}
